@@ -5,7 +5,7 @@ package Acme::CPANModules;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-01'; # DATE
 our $DIST = 'Acme-CPANModules'; # DIST
-our $VERSION = '0.1.11'; # VERSION
+our $VERSION = '0.1.12'; # VERSION
 
 1;
 # ABSTRACT: List of CPAN modules
@@ -26,7 +26,7 @@ Acme::CPANModules - List of CPAN modules
 
 =head1 VERSION
 
-This document describes version 0.1.11 of Acme::CPANModules (from Perl distribution Acme-CPANModules), released on 2023-11-01.
+This document describes version 0.1.12 of Acme::CPANModules (from Perl distribution Acme-CPANModules), released on 2023-11-01.
 
 =head1 DESCRIPTION
 
@@ -244,7 +244,7 @@ C<Acme::CPANModules::*> module. See recommendations in L</"module name">.
 =head2 module bundle abstract
 
 An C<Acme::CPANModulesBundle::> module should have abstract that begins with
-"Lists of ...".
+"Bundle of ...".
 
 =head2 other modules
 
